==> webpdf-wsclient-9.0.1-sources.jar: net/webpdf/wsclient/schema/extraction/barcode/PositionedContentElementType.java <==

package net.webpdf.wsclient.schema.extraction.barcode;

import java.util.ArrayList;
import java.util.List;
import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlSeeAlso;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <p>Java class for PositionedContentElementType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType name="PositionedContentElementType">
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element name="rectangle" type="{http://schema.webpdf.de/1.0/extraction/barcode}RectangleType" maxOccurs="unbounded"/>
 *         <choice>
 *           <element name="plain" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *         </choice>
 *       </sequence>
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "PositionedContentElementType", propOrder = {
    "rectangle",
    "plain"
})
@XmlSeeAlso({
    BarcodeType.class
})
public class PositionedContentElementType {

    @XmlElement(required = true)
    protected List<RectangleType> rectangle;
    @XmlElement(defaultValue = "")
    protected String plain;

    /**
     * Gets the value of the rectangle property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the Jakarta XML Binding object.
     * This is why there is not a {@code set} method for the rectangle property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getRectangle().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link RectangleType }
     * 
     * 
     * @return
     *     The value of the rectangle property.
     */
    public List<RectangleType> getRectangle() {
        if (rectangle == null) {
            rectangle = new ArrayList<>();
        }
        return this.rectangle;
    }

    public boolean isSetRectangle() {
        return ((this.rectangle!= null)&&(!this.rectangle.isEmpty()));
    }

    public void unsetRectangle() {
        this.rectangle = null;
    }

    /**
     * Gets the value of the plain property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPlain() {
        return plain;
    }

    /**
     * Sets the value of the plain property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPlain(String value) {
        this.plain = value;
    }

    public boolean isSetPlain() {
        return (this.plain!= null);
    }

}

==> webpdf-wsclient-9.0.2-sources.jar: net/webpdf/wsclient/schema/extraction/barcode/PositionedContentElementType.java <==

package net.webpdf.wsclient.schema.extraction.barcode;

import java.util.ArrayList;
import java.util.List;
import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlSeeAlso;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <p>Java class for PositionedContentElementType complex type</p>.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.</p>
 * 
 * <pre>{@code
 * <complexType name="PositionedContentElementType">
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element name="rectangle" type="{http://schema.webpdf.de/1.0/extraction/barcode}RectangleType" maxOccurs="unbounded"/>
 *         <choice>
 *           <element name="plain" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *         </choice>
 *       </sequence>
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "PositionedContentElementType", propOrder = {
    "rectangle",
    "plain"
})
@XmlSeeAlso({
    BarcodeType.class
})
public class PositionedContentElementType {

    @XmlElement(required = true)
    protected List<RectangleType> rectangle;
    @XmlElement(defaultValue = "")
    protected String plain;

    /**
     * Gets the value of the rectangle property.
     * 
     * <p>This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the rectangle property.</p>
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * </p>
     * <pre>
     * getRectangle().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link RectangleType }
     * </p>
     * 
     * 
     * @return
     *     The value of the rectangle property.
     */
    public List<RectangleType> getRectangle() {
        if (rectangle == null) {
            rectangle = new ArrayList<>();
        }
        return this.rectangle;
    }

    public boolean isSetRectangle() {
        return ((this.rectangle!= null)&&(!this.rectangle.isEmpty()));
    }

    public void unsetRectangle() {
        this.rectangle = null;
    }

    /**
     * Gets the value of the plain property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPlain() {
        return plain;
    }

    /**
     * Sets the value of the plain property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPlain(String value) {
        this.plain = value;
    }

    public boolean isSetPlain() {
        return (this.plain!= null);
    }

}
